@@ -8,12 +8,12 @@ describe 'Puppet::Type.type(:ironic_inspector_config)' do
 
   it 'should autorequire the package that install the file' do
     catalog = Puppet::Resource::Catalog.new
-    package = Puppet::Type.type(:package).new(:name => 'ironic-inspector')
-    catalog.add_resource package, @ironic_inspector_config
+    anchor = Puppet::Type.type(:anchor).new(:name => 'ironic::install::end')
+    catalog.add_resource anchor, @ironic_inspector_config
     dependency = @ironic_inspector_config.autorequire
     expect(dependency.size).to eq(1)
     expect(dependency[0].target).to eq(@ironic_inspector_config)
-    expect(dependency[0].source).to eq(package)
+    expect(dependency[0].source).to eq(anchor)
   end
 
 end
